@@ -1,14 +1,12 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::prelude::*;
-use crate::InetAddress;
-use crate::InetSocketAddress;
-
 use std::net::SocketAddr;
 
+use crate::{prelude::*, InetAddress, InetSocketAddress};
+
 impl From<SocketAddr> for InetSocketAddress {
     fn from(addr: SocketAddr) -> Self {
-        Self::new::<InetAddress>(&addr.ip().into(), addr.port())
+        Self::new(&InetAddress::from(addr.ip()), addr.port())
     }
 }
 
